@@ -41,7 +41,7 @@ This option is deprecated against new config option
 ``enabled_backends`` which helps to configure multiple backend stores
 of different schemes.
 
-This option is scheduled for removal in the Stein development
+This option is scheduled for removal in the U development
 cycle.
 """,
                 help="""
@@ -57,7 +57,6 @@ Possible values:
         * http
         * swift
         * rbd
-        * sheepdog
         * cinder
         * vmware
 
@@ -69,7 +68,7 @@ Related Options:
                default='file',
                choices=('file', 'filesystem', 'http', 'https', 'swift',
                         'swift+http', 'swift+https', 'swift+config', 'rbd',
-                        'sheepdog', 'cinder', 'vsphere'),
+                        'cinder', 'vsphere'),
                deprecated_for_removal=True,
                deprecated_since='Rocky',
                deprecated_reason="""
@@ -77,7 +76,7 @@ This option is deprecated against new config option
 ``default_backend`` which acts similar to ``default_store`` config
 option.
 
-This option is scheduled for removal in the Stein development
+This option is scheduled for removal in the U development
 cycle.
 """,
                help="""
@@ -101,63 +100,12 @@ Possible values:
     * swift+https
     * swift+config
     * rbd
-    * sheepdog
     * cinder
     * vsphere
 
 Related Options:
     * stores
 
-"""),
-    cfg.IntOpt('store_capabilities_update_min_interval',
-               default=0,
-               min=0,
-               deprecated_for_removal=True,
-               deprecated_since='Rocky',
-               deprecated_reason="""
-This option configures a stub method that has not been implemented
-for any existing store drivers.  Hence it is non-operational, and
-giving it a value does absolutely nothing.
-
-This option is scheduled for removal early in the Stein development
-cycle.
-""",
-               help="""
-Minimum interval in seconds to execute updating dynamic storage
-capabilities based on current backend status.
-
-Provide an integer value representing time in seconds to set the
-minimum interval before an update of dynamic storage capabilities
-for a storage backend can be attempted. Setting
-``store_capabilities_update_min_interval`` does not mean updates
-occur periodically based on the set interval. Rather, the update
-is performed at the elapse of this interval set, if an operation
-of the store is triggered.
-
-By default, this option is set to zero and is disabled. Provide an
-integer value greater than zero to enable this option.
-
-NOTE 1: For more information on store capabilities and their updates,
-please visit: https://specs.openstack.org/openstack/glance-specs/\
-specs/kilo/store-capabilities.html
-
-For more information on setting up a particular store in your
-deployment and help with the usage of this feature, please contact
-the storage driver maintainers listed here:
-https://docs.openstack.org/glance_store/latest/user/drivers.html
-
-NOTE 2: The dynamic store update capability described above is not
-implemented by any current store drivers.  Thus, this option DOES
-NOT DO ANYTHING (and it never has).  It is DEPRECATED and scheduled
-for removal early in the Stein development cycle.
-
-Possible values:
-    * Zero
-    * Positive integer
-
-Related Options:
-    * None
-
 """),
 ]
 
@@ -235,7 +183,7 @@ class Indexable(object):
 
         :param i: a slice-to-the-end
         """
-        start = i.start if isinstance(i, slice) else i
+        start = (i.start or 0) if isinstance(i, slice) else i
         if start < self.cursor:
             return self.chunk[(start - self.cursor):]
 
@@ -532,6 +480,15 @@ def add_to_backend(conf, image_id, data, size, scheme=None, context=None,
                                 verifier)
 
 
+def add_to_backend_with_multihash(conf, image_id, data, size, hashing_algo,
+                                  scheme=None, context=None, verifier=None):
+    if scheme is None:
+        scheme = conf['glance_store']['default_store']
+    store = get_store_from_scheme(scheme)
+    return store_add_to_backend_with_multihash(
+        image_id, data, size, hashing_algo, store, context, verifier)
+
+
 def set_acls(location_uri, public=False, read_tenants=[],
              write_tenants=None, context=None):
 
